==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/Sundance/src-core/FrameworkInterface/SundanceAlgebraSpecifier.hpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */

#ifndef SUNDANCE_ALGEBRASPECIFIER_HPP
#define SUNDANCE_ALGEBRASPECIFIER_HPP

#include "SundanceEnumTypeField.hpp"

namespace SundanceCore
{
using namespace SundanceUtils;

/** */
enum AlgebraType {VectorAT, NormalAT, CoordCompAT, ScalarAT};

/** AlgebraSpecifier is used to indicate whether a given object represents
 * a vector, scalar, component of a vector, etc. 
 */
class AlgebraSpecifier : public EnumTypeField<AlgebraType>
{
public:
  /** */
  AlgebraSpecifier();

  /** */
  AlgebraSpecifier(int direction);

  /** */
  AlgebraSpecifier(const AlgebraType& vct);

  /** Return true iff I am a scalar */
  bool isScalar() const {return isType(ScalarAT);}

  /** Return true iff I am a normal component of a vector */
  bool isNormal() const {return isType(NormalAT);}

  /** Return true iff I am a vector */
  bool isVector() const {return isType(VectorAT);}

  /** Return true iff I am a coordinate component of a vector */
  bool isCoordinateComponent() const {return isType(CoordCompAT);}

  /** Return coordinate direction if I am a coordinate component, 
   * otherwise, throw an exception. */
  int direction() const ;

  /** Write a string representation */
  std::string toString() const ;

  /** Comparison operator for use in sorted containers */
  bool operator<(const AlgebraSpecifier& other) const ;

private:
  int direction_;
};

/** \relates AlgebraSpecifier */
AlgebraSpecifier vectorAlgebraSpec();

/** \relates AlgebraSpecifier */
AlgebraSpecifier scalarAlgebraSpec();

/** \relates AlgebraSpecifier */
AlgebraSpecifier normalAlgebraSpec();

/** \relates AlgebraSpecifier */
AlgebraSpecifier coordAlgebraSpec(int dir);

}


namespace std
{
/** \relates AlgebraSpecifier */
ostream& operator<<(ostream& os, const SundanceCore::AlgebraSpecifier& vcs);
/** \relates AlgebraSpecifier */
ostream& operator<<(ostream& os, const SundanceCore::AlgebraType& vct);
}


#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/Sundance/src-core/FrameworkInterface/SundanceAlgebraSpecifier.hpp <==
/* @HEADER@ */
// ************************************************************************
// 
//                              Sundance
//                 Copyright (2005) Sandia Corporation
// 
// Copyright (year first published) Sandia Corporation.  Under the terms 
// of Contract DE-AC04-94AL85000 with Sandia Corporation, the U.S. Government 
// retains certain rights in this software.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//                                                                                 
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA                                                                                
// Questions? Contact Kevin Long (krlong@sandia.gov), 
// Sandia National Laboratories, Livermore, California, USA
// 
// ************************************************************************
/* @HEADER@ */

#ifndef SUNDANCE_ALGEBRASPECIFIER_HPP
#define SUNDANCE_ALGEBRASPECIFIER_HPP

#include "SundanceEnumTypeField.hpp"

namespace Sundance
{
using namespace Sundance;

/** */
enum AlgebraType {VectorAT, NormalAT, CoordCompAT, ScalarAT};

/** AlgebraSpecifier is used to indicate whether a given object represents
 * a vector, scalar, component of a vector, etc. 
 */
class AlgebraSpecifier : public EnumTypeField<AlgebraType>
{
public:
  /** */
  AlgebraSpecifier();

  /** */
  AlgebraSpecifier(int direction);

  /** */
  AlgebraSpecifier(const AlgebraType& vct);

  /** Return true iff I am a scalar */
  bool isScalar() const {return isType(ScalarAT);}

  /** Return true iff I am a normal component of a vector */
  bool isNormal() const {return isType(NormalAT);}

  /** Return true iff I am a vector */
  bool isVector() const {return isType(VectorAT);}

  /** Return true iff I am a coordinate component of a vector */
  bool isCoordinateComponent() const {return isType(CoordCompAT);}

  /** Return coordinate direction if I am a coordinate component, 
   * otherwise, throw an exception. */
  int direction() const ;

  /** Write a string representation */
  std::string toString() const ;

  /** Comparison operator for use in sorted containers */
  bool operator<(const AlgebraSpecifier& other) const ;

private:
  int direction_;
};

/** \relates AlgebraSpecifier */
AlgebraSpecifier vectorAlgebraSpec();

/** \relates AlgebraSpecifier */
AlgebraSpecifier scalarAlgebraSpec();

/** \relates AlgebraSpecifier */
AlgebraSpecifier normalAlgebraSpec();

/** \relates AlgebraSpecifier */
AlgebraSpecifier coordAlgebraSpec(int dir);

}


namespace std
{
/** \relates AlgebraSpecifier */
ostream& operator<<(ostream& os, const Sundance::AlgebraSpecifier& vcs);
/** \relates AlgebraSpecifier */
ostream& operator<<(ostream& os, const Sundance::AlgebraType& vct);
}


#endif
